summaryrefslogtreecommitdiffstats
path: root/lib/kofficeui/KoSelectAction.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kofficeui/KoSelectAction.h')
-rw-r--r--lib/kofficeui/KoSelectAction.h21
1 files changed, 11 insertions, 10 deletions
diff --git a/lib/kofficeui/KoSelectAction.h b/lib/kofficeui/KoSelectAction.h
index 6cdae7c4d..4bad1005c 100644
--- a/lib/kofficeui/KoSelectAction.h
+++ b/lib/kofficeui/KoSelectAction.h
@@ -22,7 +22,7 @@
#include <kaction.h>
#include <koffice_export.h>
class KPopupMenu;
-class QPoint;
+class TQPoint;
/** An action that provides a menu with items that can be selected.
* The main difference between this action and a KSelectAction is that
@@ -31,24 +31,25 @@ class QPoint;
class KOFFICEUI_EXPORT KoSelectAction : public KAction
{
Q_OBJECT
+ TQ_OBJECT
public:
/** Constructs a KoSelectAction with a text and an icon.
* @param text The text that will be displayed.
* @param icon The dynamically loaded icon that goes with this action.
* @param parent This action's parent.
* @param name An internal name for this action.
*/
- KoSelectAction(const QString& text, const QString& icon, QObject* parent = 0, const char* name = 0);
+ KoSelectAction(const TQString& text, const TQString& icon, TQObject* tqparent = 0, const char* name = 0);
/** Same as above, but it also connects a slot to the selectionChanged(int) signal.
* @param text The text that will be displayed.
* @param icon The dynamically loaded icon that goes with this action.
* @param receiver The SLOT's parent.
* @param slot The SLOT to invoke when a selectionChanged(int) signal is emited.
* @param parent This action's parent.
* @param name An internal name for this action.
*/
- KoSelectAction(const QString& text, const QString& icon, const QObject* receiver,
- const char* slot, QObject* parent, const char* name = 0);
+ KoSelectAction(const TQString& text, const TQString& icon, const TQObject* receiver,
+ const char* slot, TQObject* tqparent, const char* name = 0);
~KoSelectAction();
/** Returns a pointer to the popup menu. */
@@ -56,9 +57,9 @@ class KOFFICEUI_EXPORT KoSelectAction : public KAction
/** Shows the popup menu.
* @param global Position at which the popup menu is shown.
*/
- void popup(const QPoint& global);
+ void popup(const TQPoint& global);
- virtual int plug(QWidget* widget, int index = -1);
+ virtual int plug(TQWidget* widget, int index = -1);
/** Returns the index of the currently selected item. */
virtual int currentSelection();
@@ -31,24 +31,25 @@ class QPoint;
* @param text The text that will be displayed.
* @param icon The dynamically loaded icon that goes with this action.
- * @param parent This action's parent.
+ * @param tqparent This action's tqparent.
* @param name An internal name for this action.
*/
@@ -31,24 +31,25 @@ class QPoint;
* @param text The text that will be displayed.
* @param icon The dynamically loaded icon that goes with this action.
- * @param receiver The SLOT's parent.
- * @param slot The SLOT to invoke when a selectionChanged(int) signal is emited.
- * @param parent This action's parent.
+ * @param receiver The SLOT's tqparent.
+ * @param slot The TQT_SLOT to invoke when a selectionChanged(int) signal is emited.
+ * @param tqparent This action's tqparent.
* @param name An internal name for this action.
*/